.. multiprocessing documentation master file, created by sphinx-quickstart on Wed Nov 26 12:47:00 2008.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to multiprocessing's documentation!
===========================================

Contents:

.. toctree::

    library/multiprocessing.rst
    glossary.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

